@@ -1,11 +1,13 @@
 import json
-from typing import Optional
+from typing import Optional, Union, List, Tuple
 from PySide2.QtCore import Qt
 from PySide2.QtGui import QColor
 from PySide2.QtWidgets import QApplication, QFileDialog, QInputDialog, QLineEdit, QMessageBox
 
-from angrmanagement.plugins.trace_viewer.qtrace_viewer import QTraceViewer
-
+from .qtrace_viewer import QTraceViewer
+from ...data.object_container import ObjectContainer
+from ...logic import GlobalInfo
+from ...logic.threads import gui_thread_schedule_async
 from ...utils.io import isurl, download_url
 from ...errors import InvalidURLError, UnexpectedStatusCodeError
 from ..base_plugin import BasePlugin
@@ -23,8 +25,6 @@ class TraceViewer(BasePlugin):
         self.workspace.instance.register_container('multi_trace', lambda: None, Optional[MultiTrace],
                                                    'The current set of multiple traces')
 
-        self.workspace.instance.register_method('open_bitmap_multi_trace', self.open_bitmap_multi_trace)
-
         # Register event callbacks
         self.trace.am_subscribe(self._on_trace_updated)
         self.multi_trace.am_subscribe(self._on_trace_updated)
@@ -41,11 +41,11 @@ class TraceViewer(BasePlugin):
     #
 
     @property
-    def trace(self) -> Optional[TraceStatistics]:
+    def trace(self) -> Union[ObjectContainer, Optional[TraceStatistics]]:
         return self.workspace.instance.trace
 
     @property
-    def multi_trace(self) -> Optional[MultiTrace]:
+    def multi_trace(self) -> Union[ObjectContainer, Optional[MultiTrace]]:
         return self.workspace.instance.multi_trace
 
 
@@ -59,6 +59,23 @@ class TraceViewer(BasePlugin):
         # refresh function table
         self.workspace.view_manager.first_view_in_category('functions').refresh()
 
+    URL_ACTIONS = ['openbitmap']
+
+    def handle_url_action(self, action, kwargs):
+        if action == 'openbitmap':
+            try:
+                base = int(kwargs['base'], 16)
+            except (ValueError, KeyError):
+                base = None
+            gui_thread_schedule_async(GlobalInfo.main_window.bring_to_front)
+            gui_thread_schedule_async(self.open_bitmap_multi_trace,
+                                      args=(kwargs['path'],),
+                                      kwargs={
+                                          'base_addr': base,
+                                      })
+        else:
+            raise ValueError("Trace plugin cannot handle url action " + action)
+
     #
     # features for the disassembly view
     #
@@ -74,7 +91,7 @@ class TraceViewer(BasePlugin):
         trace_viewer.hide()
 
     def color_block(self, addr):
-        if self.multi_trace != None:
+        if not self.multi_trace.am_none:
             return self.multi_trace.get_hit_miss_color(addr)
         return None
 
@@ -82,7 +99,7 @@ class TraceViewer(BasePlugin):
         btn = event.button()
 
         if QApplication.keyboardModifiers() == Qt.ControlModifier and btn == Qt.RightButton:
-            if self.multi_trace is not None:
+            if self.multi_trace is not None and self.multi_trace.am_obj is not None:
                 the_trace = self.multi_trace.get_any_trace(qblock.addr)
                 if the_trace is not None:
                     self.trace.am_obj = TraceStatistics(self.workspace, the_trace, self.multi_trace.base_addr)
@@ -104,7 +121,7 @@ class TraceViewer(BasePlugin):
                 legend_x += w
 
     def _gen_strata(self, addr):
-        if self.trace != None:
+        if not self.trace.am_none:
             # count is cached in trace.
             count = self.trace.get_count(addr)
 
@@ -125,10 +142,10 @@ class TraceViewer(BasePlugin):
     #
 
     def color_func(self, func):
-        if self.multi_trace != None:
+        if not self.multi_trace.am_none:
             return self.multi_trace.get_percent_color(func)
 
-        if self.trace != None:
+        if not self.trace.am_none:
             for itr_func in self.trace.trace_func:
                 if itr_func.bbl_addr == func.addr:
                     return QColor(0xf0, 0xe7, 0xda)
@@ -139,7 +156,7 @@ class TraceViewer(BasePlugin):
 
     def extract_func_column(self, func, idx):
         assert idx == 0
-        if self.multi_trace == None:
+        if self.multi_trace.am_none:
             cov = 0
             rend = ''
         else:
@@ -172,7 +189,7 @@ class TraceViewer(BasePlugin):
         if idx < 0 or idx >= len(self.MENU_BUTTONS):
             return
 
-        if self.workspace.instance.project is None:
+        if self.workspace.instance.project.am_none:
             return
 
         mapping = {
@@ -187,19 +204,16 @@ class TraceViewer(BasePlugin):
         mapping.get(idx)()
 
     def open_trace(self):
-        trace, baddr = self._open_json_trace_dialog()
-        if baddr is None:
+        trace, base_addr = self._open_json_trace_dialog()
+        if trace is None or base_addr is None:
             return
 
-        self.trace.am_obj = TraceStatistics(self.workspace, trace, baddr)
+        self.trace.am_obj = TraceStatistics(self.workspace, trace, base_addr)
         self.trace.am_event()
 
     def open_multi_trace(self):
-        trace = self._open_json_trace_dialog()
-        if trace is None:
-            return
-        base_addr = self._open_baseaddr_dialog(0x0)
-        if base_addr is None:
+        trace, base_addr = self._open_json_trace_dialog()
+        if trace is None or base_addr is None:
             return
 
         self.multi_trace.am_obj = MultiTrace(self.workspace, trace, base_addr)
@@ -282,14 +296,22 @@ class TraceViewer(BasePlugin):
         except ValueError:
             return None
 
-    def _open_json_trace_dialog(self):
+    def _open_json_trace_dialog(self) -> Tuple[Optional[List[int]],Optional[int]]:
         project = self.workspace.instance.project
         trace_file_name = self._open_trace_dialog(filter='json (*.json)')
-        base_addr = self._open_baseaddr_dialog(project.loader.main_object.mapped_base)
 
-        if trace_file_name is None or base_addr is None:
+        if trace_file_name is None:
             return None, None
 
         with open(trace_file_name, 'r') as f:
             trace = json.load(f)
+
+        if not isinstance(trace, list):
+            QMessageBox.critical(self.workspace._main_window,
+                                 "Incorrect trace format",
+                                 "Failed to open the JSON trace. We expect the JSON trace to be a list of integers.")
+            return None, None
+
+        base_addr = self._open_baseaddr_dialog(0x4000000000)
+
         return trace, base_addr
