@@ -7,6 +7,6 @@ from .strings_view import StringsView
 from .console_view import ConsoleView
 from .code_view import CodeView
 from .interaction_view import InteractionView
-from .sync_view import SyncView
 from .patches_view import PatchesView
 from .dep_view import DependencyView
+from .proximity_view import ProximityView
