@@ -1,8 +1,8 @@
 import logging
 from typing import Union, Optional, TYPE_CHECKING
 
-from PySide2.QtWidgets import QHBoxLayout, QVBoxLayout, QMenu, QApplication, QMessageBox
-from PySide2.QtCore import Qt, QSize
+from PySide2.QtWidgets import QHBoxLayout, QVBoxLayout, QApplication, QMessageBox
+from PySide2.QtCore import Qt, QSize, Signal
 
 from ...data.instance import ObjectContainer
 from ...utils import locate_function
@@ -27,8 +27,10 @@ _l = logging.getLogger(__name__)
 
 
 class DisassemblyView(BaseView):
+    view_visibility_changed = Signal()
+
     def __init__(self, workspace, *args, **kwargs):
-        super(DisassemblyView, self).__init__('disassembly', workspace, *args, **kwargs)
+        super().__init__('disassembly', workspace, *args, **kwargs)
 
         self.caption = 'Disassembly'
 
@@ -52,6 +54,10 @@ class DisassemblyView(BaseView):
         self._label_menu = None  # type: Optional[DisasmLabelContextMenu]
 
         self._insn_addr_on_context_menu = None
+        self._label_addr_on_context_menu = None
+
+        self.width_hint = 800
+        self.height_hint = 800
 
         self._init_widgets()
         self._init_menus()
@@ -172,18 +178,6 @@ class DisassemblyView(BaseView):
     #
 
     def keyPressEvent(self, event):
-        key = event.key()
-        if key == Qt.Key_Escape:
-            # jump back
-            # we put it here because the escape key is used to close other dialogs, and we do not want to catch the
-            # key-release event of the escape key in such cases.
-            self.jump_back()
-            return
-
-        super().keyPressEvent(event)
-
-
-    def keyReleaseEvent(self, event):
         key = event.key()
         if key == Qt.Key_G:
             # jump to window
@@ -214,10 +208,14 @@ class DisassemblyView(BaseView):
             self.toggle_disasm_view()
             event.accept()
             return
+        elif key == Qt.Key_Escape:
+            # jump back
+            self.jump_back()
+            return
 
-        super().keyReleaseEvent(event)
+        super().keyPressEvent(event)
 
-    def redraw_current_graph(self, **kwargs):
+    def redraw_current_graph(self, **kwargs):  # pylint: disable=unused-argument
         """
         Redraw the graph currently in display.
 
@@ -281,8 +279,7 @@ class DisassemblyView(BaseView):
         else:
             dialog.exec_()
 
-    def popup_dependson_dialog(self, addr: Optional[int]=None, use_operand=False, func: bool=False,
-                               async_=True):
+    def popup_dependson_dialog(self, addr: Optional[int]=None, use_operand=False, func: bool=False):
         if use_operand:
             r = self._flow_graph.get_selected_operand_info()
             if r is not None:
@@ -374,6 +371,7 @@ class DisassemblyView(BaseView):
             self._flow_graph.show_instruction(self._current_function.addr)
 
         self._flow_graph.setFocus()
+        self.view_visibility_changed.emit()
 
     def display_linear_viewer(self):
 
@@ -387,6 +385,7 @@ class DisassemblyView(BaseView):
             self._linear_viewer.show_instruction(self._current_function.addr)
 
         self._linear_viewer.setFocus()
+        self.view_visibility_changed.emit()
 
     def display_function(self, function):
 
@@ -470,26 +469,26 @@ class DisassemblyView(BaseView):
                 self._flow_graph.function_graph.clear_cache()
                 self._flow_graph.reload()
 
-    def jump_to(self, addr, src_ins_addr=None):
+    def jump_to(self, addr, src_ins_addr=None, use_animation=False):
 
         # Record the current instruction address first
         if src_ins_addr is not None:
             self._jump_history.record_address(src_ins_addr)
 
         self._jump_history.jump_to(addr)
-        self._jump_to(addr)
+        self._jump_to(addr, use_animation=use_animation)
 
         return True
 
     def jump_back(self):
         addr = self._jump_history.backtrack()
         if addr is not None:
-            self._jump_to(addr)
+            self._jump_to(addr, use_animation=False)
 
     def jump_forward(self):
         addr = self._jump_history.forwardstep()
         if addr is not None:
-            self._jump_to(addr)
+            self._jump_to(addr, use_animation=False)
 
     def select_label(self, label_addr):
         self.infodock.select_label(label_addr)
@@ -519,9 +518,6 @@ class DisassemblyView(BaseView):
 
         self.workspace.view_manager.first_view_in_category('symexec').avoid_addr_in_exec(addr)
 
-    def sizeHint(self):
-        return QSize(800, 800)
-
     def run_induction_variable_analysis(self):
         if self._flow_graph.induction_variable_analysis:
             self._flow_graph.induction_variable_analysis = None
@@ -614,14 +610,14 @@ class DisassemblyView(BaseView):
             'function_': the_func,
         })
 
-    def _jump_to(self, addr):
+    def _jump_to(self, addr, use_animation=False):
         function = locate_function(self.workspace.instance, addr)
         if function is not None:
             self._display_function(function)
             instr_addr = function.addr_to_instruction_addr(addr)
             if instr_addr is None:
                 instr_addr = addr
-            self.infodock.select_instruction(instr_addr, unique=True)
+            self.infodock.select_instruction(instr_addr, unique=True, use_animation=use_animation)
             return True
 
         # it does not belong to any function - we need to switch to linear view mode
