@@ -1,5 +1,6 @@
 from typing import TYPE_CHECKING
 
+import PySide2.QtGui
 from PySide2.QtWidgets import QFrame
 from PySide2.QtCore import QSize
 
@@ -23,6 +24,9 @@ class BaseView(QFrame):
         self.width_hint = -1
         self.height_hint = -1
 
+    def focus(self):
+        self.workspace.view_manager.raise_view(self)
+
     def reload(self):
         pass
 
@@ -36,3 +40,7 @@ class BaseView(QFrame):
 
     def is_shown(self):
         return self.visibleRegion().isEmpty() is False
+
+    def closeEvent(self, event:PySide2.QtGui.QCloseEvent):
+        self.workspace.view_manager.remove_view(self)
+        event.accept()
