@@ -5,7 +5,6 @@ from pyqodeng.core.api import SyntaxHighlighter
 from PySide2.QtGui import QTextCharFormat, QFont
 from PySide2.QtCore import Qt
 
-from ...config import Conf
 from ..documents import QCodeDocument
 
 
@@ -21,10 +20,13 @@ class QCCodeHighlighter(SyntaxHighlighter):
 
     HIGHLIGHTING_RULES = [
         # quotation
-        (r"\".*\"", 'quotation'),
+        #(r"\"([^\\\"]|(\\.))*\"", 'quotation'),
         # comment
-        (r"//[^\n]*", 'comment'),
-        (r"/\*[^\n]*\*/", 'comment'),
+        #(r"//[^\n]*", 'comment'),
+        #(r"/\*[^\n]*\*/", 'comment'),
+        # function
+        (r"\b[A-Za-z0-9_:]+\s*(?=\()", 'function'),
+        (r"\bNULL\b", 'function'),
         # keywords
         (r"\bbool\b", 'keyword'),
         (r"\bbreak\b", 'keyword'),
@@ -73,8 +75,6 @@ class QCCodeHighlighter(SyntaxHighlighter):
         (r"\bwhile\b", 'keyword'),
         (r"\bswitch\b", 'keyword'),
         (r"\breturn\b", 'keyword'),
-        # function
-        (r"\b[A-Za-z0-9_:]+(?=\()", 'function'),
     ]
 
     def __init__(self, parent, color_scheme=None):
@@ -82,6 +82,7 @@ class QCCodeHighlighter(SyntaxHighlighter):
         super().__init__(parent, color_scheme=color_scheme)
 
         self.doc = parent  # type: QCodeDocument
+        self.comment_status = False
 
         if FORMATS['keyword'] is None:
             f = QTextCharFormat()
@@ -104,11 +105,62 @@ class QCCodeHighlighter(SyntaxHighlighter):
             FORMATS['comment'] = f
 
     def highlight_block(self, text, block):
+        # this code makes the assumption that this function is only ever called on lines in sequence in order
+        # it might also fuck up if it ever calls it starting in the middle...
+        if block.previous() is None:
+            self.comment_status = False
+
+        mark_in = 0
+
+        quote_status = False
+        quote_mark = None
+        escape_counter = 0
+        for col in range(len(text)):
+            if quote_status:
+                assert not self.comment_status
+                if escape_counter:
+                    escape_counter -= 1
+                elif text[col] == '\\':
+                    escape_counter = 1
+                elif text[col] == quote_mark:
+                    quote_status = False
+                    mark_out = col + 1
+                    self.setFormat(mark_in, mark_out - mark_in, FORMATS['quotation'])
+                    text = text[:mark_in] + " " * (mark_out - mark_in) + text[mark_out:]
+            else:
+                if self.comment_status:
+                    if text[col:col+2] == "*/":
+                        mark_out = col + 2
+                        self.comment_status = False
+                        self.setFormat(mark_in, mark_out - mark_in, FORMATS['comment'])
+                        text = text[:mark_in] + " " * (mark_out - mark_in) + text[mark_out:]
+                else:
+                    # regular mode is here
+                    if text[col] in ('"', "'"):
+                        mark_in = col
+                        quote_status = True
+                        quote_mark = text[col]
+                    elif text[col:col+2] == "/*":
+                        mark_in = col
+                        self.comment_status = True
+                    elif text[col:col+2] == '//':
+                        # do not set comment_status. just format the line and break.
+                        mark_in = col
+                        mark_out = len(text)
+                        self.setFormat(mark_in, mark_out - mark_in, FORMATS['comment'])
+                        text = text[:mark_in] + " " * (mark_out - mark_in) + text[mark_out:]
+                        break
+        if self.comment_status:
+            # do not unset. this is a multiline comment
+            mark_out = len(text)
+            self.setFormat(mark_in, mark_out - mark_in, FORMATS['comment'])
+            text = text[:mark_in] + " " * (mark_out - mark_in) + text[mark_out:]
+
         for pattern, format_id in self.HIGHLIGHTING_RULES:
             for mo in list(re.finditer(pattern, text)):
                 start = mo.start()
                 end = mo.end()
                 self.setFormat(start, end - start, FORMATS[format_id])
-                if format_id in {'quotation', 'comment'}:
-                    # remove the formatted parts so that we do not end up highlighting these parts again
-                    text = text[:start] + " " * (end-start) + text[end:]
+                #if format_id in {'quotation', 'comment'}:
+                #    # remove the formatted parts so that we do not end up highlighting these parts again
+                #    text = text[:start] + " " * (end-start) + text[end:]
